@@ -148,12 +148,17 @@ async def new_position(
     limit_price: float,
     selling: str,
     session: aiohttp.ClientSession,
+
 ):
     try:
-        logging.info(f"\tPlaceOrders: Placing New Order. Selling: {selling}")
         first_currency_code, second_currency_code = market_code.split("/")
+
+        logging.info(
+            f"\n\tPlaceOrders: Placing New Order {first_currency_code}{second_currency_code}. Selling: {selling}")
         limit_price = limit_price * 10 ** CEROS[second_currency_code]
         amount = amount * 10 ** CEROS[first_currency_code]
+        logging.info(f"\t\tLimit Price: {limit_price}")
+        logging.info(f"\t\tAmount: {amount}")
 
         query_place_order = get_new_position_query(
             market_code=market_code.replace("/", ""),
